@@ -2,6 +2,7 @@ tol_large = 1e-10
 
 # Multiple groups / outcomes: effect size estimates
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: SMD", {
+  skip_on_cran()
   df <- df.SMD;   df$factor <- "Pharma"; df$amstar <- 7
 
   df$author[c(2,3, 5,6,7, 15,16,17)] <- c(df$author[1], df$author[1],
@@ -46,6 +47,7 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 
 
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: OR", {
+  skip_on_cran()
   df <- df.OR.multi
 
   df.format.transit <- .quiet(.format_dataset(attr(.check_data(df), "data"), mult.level = TRUE))
@@ -80,6 +82,7 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 })
 
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: RR", {
+  skip_on_cran()
   df <- df.OR.multi
   df$measure <- "RR"
   df.format.transit <- .quiet(.format_dataset(attr(.check_data(df), "data"), mult.level = TRUE))
@@ -112,6 +115,7 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 })
 
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: IRR", {
+  skip_on_cran()
   df <- df.IRR
   df$measure <- "IRR"
   df$author[c(2,3, 5,6,7, 15,16)] <- c(df$author[1], df$author[1],
@@ -156,6 +160,7 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 })
 
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: HR", {
+  skip_on_cran()
   df <- df.OR.multi
   df$measure <- "HR"
 df$n_cases = with(df, n_cases_exp + n_cases_nexp)
@@ -192,6 +197,7 @@ df$n_controls = with(df, n_controls_exp + n_controls_nexp)
 ###############################################################################################
 # Multiple groups / outcomes: effect size estimates
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: SMD", {
+  skip_on_cran()
   df <- df.SMD;   df$factor <- "Pharma"; df$amstar <- 7
   D = with(df, .estimate_d_from_means(n_cases, n_controls, mean_cases, sd_cases, mean_controls, sd_controls))
   G = with(df, .estimate_g_from_d(value, n_cases, n_controls))
@@ -254,6 +260,7 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 
 ## MULT GROUPS - OR
 test_that("correct aggregation multiple groups", {
+  skip_on_cran()
   df <- subset(df.OR.multi, meta_review == "Huynh")
 
   umb <- umbrella(df, mult.level = TRUE, method.var = "REML", verbose = FALSE)[[1]]$random
@@ -276,6 +283,7 @@ test_that("correct aggregation multiple groups", {
 
 ## MULT OUTCOMES - OR
 test_that("correct aggregation multiple outcomes", {
+  skip_on_cran()
   df <- subset(df.OR.multi, meta_review == "el-Abood")
 
   umb <- umbrella(df, mult.level = TRUE, method.var = "REML", verbose = FALSE)[[1]]$random
@@ -301,6 +309,7 @@ test_that("correct aggregation multiple outcomes", {
 
 ## MULT GROUPS - RR
 test_that("correct aggregation multiple groups", {
+  skip_on_cran()
   df <- subset(df.OR.multi, meta_review == "Huynh", select = -c(value, ci_lo, ci_up))
   df$measure = "RR"
 
@@ -327,6 +336,7 @@ test_that("correct aggregation multiple groups", {
 
 ## MULT OUTCOMES - OR
 test_that("correct aggregation multiple outcomes", {
+  skip_on_cran()
   df <- subset(df.OR.multi, meta_review == "el-Abood", select = -c(value, ci_lo, ci_up))
   df$measure = "RR"
 
@@ -356,6 +366,7 @@ test_that("correct aggregation multiple outcomes", {
 
 ## MULT GROUPS - HR
 test_that("correct aggregation multiple groups", {
+  skip_on_cran()
   df = df.OR.multi
   df$n_cases = with(df, n_cases_exp + n_cases_nexp)
   df$n_controls = with(df, n_controls_exp + n_controls_nexp)
@@ -379,6 +390,7 @@ test_that("correct aggregation multiple groups", {
 
 ## MULT OUTCOMES - HR
 test_that("correct aggregation multiple outcomes", {
+  skip_on_cran()
   df = df.OR.multi
   df$n_cases = with(df, n_cases_exp + n_cases_nexp)
   df$n_controls = with(df, n_controls_exp + n_controls_nexp)
@@ -408,6 +420,7 @@ test_that("correct aggregation multiple outcomes", {
 
 # CORRECTION FACTOR - simple level
 test_that(".shared_adjustment_mod provides adequate sample size correction for standard situations", {
+  skip_on_cran()
   df <- df.SMD[1:5,]
 
   df$shared_controls <- c(1,2,2,1,1)
@@ -419,6 +432,7 @@ test_that(".shared_adjustment_mod provides adequate sample size correction for s
 
 # CORRECTION FACTOR - multi level
 test_that(".shared_adjustment_mod provides adequate sample size correction for multilevel situations", {
+  skip_on_cran()
   df <- df.SMD[1:5,]
 
   df$author[c(4)] <- c(df$author[1])
@@ -436,6 +450,7 @@ test_that(".shared_adjustment_mod provides adequate sample size correction for m
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - SMD
 test_that(".shared_adjustment_mod provides adequate sample size and effect size correction for STANDARD situations SMD", {
+  skip_on_cran()
   df <- df.SMD[1:5,]
 
   df$shared_controls <- c(1,2,2,3,4)
@@ -476,7 +491,7 @@ test_that(".shared_adjustment_mod provides adequate sample size and effect size
 
   expect_equal(df_adj[2:3, ]$n_cases_raw, df[2:3, ]$n_cases)
   expect_equal(df_adj[2:3, ]$n_controls_adj, df[2:3, ]$n_controls / 2, tolerance = tol_large)
-  expect_equal(sum(df_adj$n_cases_adj, df_adj$n_controls_adj), umb$Pharmacological$n$cases_and_controls, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_adj, df_adj$n_controls_adj), umb$Pharmacological$n$total_n, tolerance = tol_large)
 
   expect_equal(df_adj$ci_lo_adj[2], ci_loG1, tolerance = tol_large)
   expect_equal(df_adj$ci_up_adj[2], ci_upG1, tolerance = tol_large)
@@ -485,6 +500,7 @@ test_that(".shared_adjustment_mod provides adequate sample size and effect size
 })
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - multilevel - SMD
 test_that(".shared_adjustment_mod provides adequate sample size and effect size correction for MULTILEVEL situations SMD", {
+  skip_on_cran()
   df <- df.SMD[1:5,]
 
   df$shared_controls <- c(1,2,2,1,1)
@@ -534,11 +550,12 @@ test_that(".shared_adjustment_mod provides adequate sample size and effect size
   expect_equal(df_adj$ci_up_adj[1], ci_upG1, tolerance = tol_large)
   expect_equal(df_adj$ci_lo_adj[4], ci_loG4, tolerance = tol_large)
   expect_equal(df_adj$ci_up_adj[4], ci_upG4, tolerance = tol_large)
-  expect_equal(sum(df_adj$n_cases_raw[2:5], df_adj$n_controls_adj[2:5]), umb$Pharmacological$n$cases_and_controls, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_raw[2:5], df_adj$n_controls_adj[2:5]), umb$Pharmacological$n$total_n, tolerance = tol_large)
 
 })
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - OR - shared_controls
 test_that("shared_controls provides adequate sample size and effect size correction for STANDARD situations OR", {
+  skip_on_cran()
   df <- df.OR[1:5,]
 
   df$shared_controls <- c(1,2,2,3,4)
@@ -567,7 +584,7 @@ test_that("shared_controls provides adequate sample size and effect size correct
 
   expect_equal(df_adj[2:3, ]$n_cases_raw, df[2:3, ]$n_cases)
   expect_equal(df_adj[2:3, ]$n_controls_adj, df[2:3, ]$n_controls / 2, tolerance = tol_large)
-  expect_equal(sum(df_adj$n_cases_raw, df_adj$n_controls_adj), umb$ADHD$n$cases_and_controls, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_raw, df_adj$n_controls_adj), umb$ADHD$n$total_n, tolerance = tol_large)
   expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]), tolerance = tol_large)
   expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = tol_large)
   expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = tol_large)
@@ -575,6 +592,7 @@ test_that("shared_controls provides adequate sample size and effect size correct
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - OR - shared_nexp
 test_that("shared_nexp provides adequate sample size and effect size correction for STANDARD situations OR", {
+  skip_on_cran()
   df <- df.OR[1:5,]
 
   df$shared_nexp <- c(1,2,2,3,4)
@@ -611,6 +629,7 @@ test_that("shared_nexp provides adequate sample size and effect size correction
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - multilevel - OR - shared_nexp
 test_that("shared_controls provides adequate sample size and effect size correction for multilevel situations OR", {
+  skip_on_cran()
   df <- df.OR[1:5,]
 
   df$shared_controls <- c(1,2,2,1,1)
@@ -649,11 +668,12 @@ test_that("shared_controls provides adequate sample size and effect size correct
   expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
   expect_equal(df_adj$ci_lo_adj, ci_lo, tolerance = tol_large)
   expect_equal(df_adj$ci_up_adj, ci_up, tolerance = tol_large)
-  expect_equal(sum(df_adj$n_cases_adj[c(1:3,5)], df_adj$n_controls_adj[c(1:3,5)]), umb$ADHD$n$cases_and_controls, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_adj[c(1:3,5)], df_adj$n_controls_adj[c(1:3,5)]), umb$ADHD$n$total_n, tolerance = tol_large)
 })
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple MULTILEVEL - OR - shared_nexp
 test_that("shared_nexp provides adequate sample size and effect size correction for MULTILEVEL situations OR", {
+  skip_on_cran()
   df <- df.OR[1:5,]
 
   df$shared_nexp <- c(1,2,2,1,1)
@@ -690,12 +710,13 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
   expect_equal(df_adj$ci_lo_adj, ci_lo, tolerance = tol_large)
   expect_equal(df_adj$ci_up_adj, ci_up, tolerance = tol_large)
-  expect_equal(sum(df_adj$n_cases_adj[c(1:3,5)], df_adj$n_controls_adj[c(1:3,5)]), umb$ADHD$n$cases_and_controls, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_adj[c(1:3,5)], df_adj$n_controls_adj[c(1:3,5)]), umb$ADHD$n$total_n, tolerance = tol_large)
 })
 
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - RR
 test_that("shared_nexp provides adequate sample size and effect size correction for STANDARD situations RR", {
+  skip_on_cran()
   df <- df.RR[1:5,]
 
   df$shared_nexp <- c(1,2,2,3,4)
@@ -738,6 +759,7 @@ test_that("shared_nexp provides adequate sample size and effect size correction
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - IRR
 test_that("shared_nexp provides adequate sample size and effect size correction for STANDARD situations RR", {
+  skip_on_cran()
 
   df <- df.IRR[1:5,]
 
@@ -775,6 +797,6 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]))
   expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = tol_large)
   expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = tol_large)
-  expect_equal(sum(df_adj$n_cases_adj), umb$Smoking$n$cases_and_controls, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_adj), umb$Smoking$n$total_n, tolerance = tol_large)
 })
 
